==> haskell-githash-0.1.6.3-127-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-githash.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 githash
version:              0.1.6.3
visibility:           public
id:                   githash-0.1.6.3-FAbCcdm45dU3zzfkwbhkak
key:                  githash-0.1.6.3-FAbCcdm45dU3zzfkwbhkak
license:              BSD-3-Clause
maintainer:           michael@snoyman.com
author:               Michael Snoyman, Adam C. Foltzer
homepage:             https://github.com/snoyberg/githash#readme
synopsis:             Compile git revision info into Haskell projects
description:
    Please see the README and documentation at <https://www.stackage.org/package/githash>

category:             Development
abi:                  10505eaf38039c94e437d523c74d8d86
exposed:              True
exposed-modules:      GitHash
hidden-modules:       Paths_githash
import-dirs:          /usr/lib/ghc-9.2.8/site-local/githash-0.1.6.3
library-dirs:         /usr/lib/ghc-9.2.8/site-local/githash-0.1.6.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-githash
hs-libraries:         HSgithash-0.1.6.3-FAbCcdm45dU3zzfkwbhkak
depends:
    base-4.16.4.0 bytestring-0.11.4.0 directory-1.3.6.2
    filepath-1.4.2.2 process-1.6.16.0 template-haskell-2.18.0.0
    th-compat-0.1.5-IvB9HRan0b6IGinXr0IRBr

haddock-interfaces:   /usr/share/doc/haskell-githash/html/githash.haddock
haddock-html:         /usr/share/doc/haskell-githash/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-githash-0.1.6.3-145-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-githash.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 githash
version:              0.1.6.3
visibility:           public
id:                   githash-0.1.6.3-IX1GqAmi93MLlgt20beGip
key:                  githash-0.1.6.3-IX1GqAmi93MLlgt20beGip
license:              BSD-3-Clause
maintainer:           michael@snoyman.com
author:               Michael Snoyman, Adam C. Foltzer
homepage:             https://github.com/snoyberg/githash#readme
synopsis:             Compile git revision info into Haskell projects
description:
    Please see the README and documentation at <https://www.stackage.org/package/githash>

category:             Development
abi:                  a3783dc23df0ef27c26cf7e910f50490
exposed:              True
exposed-modules:      GitHash
hidden-modules:       Paths_githash
import-dirs:          /usr/lib/ghc-9.2.8/site-local/githash-0.1.6.3
library-dirs:         /usr/lib/ghc-9.2.8/site-local/githash-0.1.6.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-githash
hs-libraries:         HSgithash-0.1.6.3-IX1GqAmi93MLlgt20beGip
depends:
    base-4.16.4.0 bytestring-0.11.4.0 directory-1.3.6.2
    filepath-1.4.2.2 process-1.6.16.0 template-haskell-2.18.0.0
    th-compat-0.1.5-4ANVl8iXfARG697rrs9EPv

haddock-interfaces:   /usr/share/doc/haskell-githash/html/githash.haddock
haddock-html:         /usr/share/doc/haskell-githash/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
